@@ -109,7 +109,7 @@ osl_arrays_p    osl_arrays_sread(char **);
 /*+***************************************************************************
  *                    Memory allocation/deallocation function                *
  *****************************************************************************/
-osl_arrays_p    osl_arrays_malloc();
+osl_arrays_p    osl_arrays_malloc(void);
 void            osl_arrays_free(osl_arrays_p);
 
 
@@ -119,7 +119,10 @@ void            osl_arrays_free(osl_arrays_p);
 osl_arrays_p    osl_arrays_clone(osl_arrays_p);
 int             osl_arrays_equal(osl_arrays_p, osl_arrays_p);
 osl_strings_p   osl_arrays_to_strings(osl_arrays_p);
-osl_interface_p osl_arrays_interface();
+int             osl_arrays_add(osl_arrays_p, int, char*);
+size_t          osl_arrays_get_index_from_id(osl_arrays_p, int);
+size_t          osl_arrays_get_index_from_name(osl_arrays_p, char*);
+osl_interface_p osl_arrays_interface(void);
 
 # if defined(__cplusplus)
   }
