@@ -971,6 +971,39 @@ void osl_int_gcd(int const precision, osl_int_const_p gcd,
   }
 }
 
+/**
+ * \brief Compute the least common multiple (lcm) of two numbers a and b.
+ * For negative numbers, gives the least positive common multiple.
+ * \param[in]  precision Precision of the osl int
+ * \param[out] lcm       Least common multiple
+ * \param[in]  a         Value of first osl int
+ * \param[in]  b         Value of second osl int
+ */
+void osl_int_lcm(int const precision, osl_int_p lcm,
+                 osl_const_int_t a, osl_const_int_t b) {
+  osl_int_t gcd;
+  osl_int_t pa, pb;
+
+  osl_int_init(precision, &gcd);
+  osl_int_init(precision, &pa);
+  osl_int_init(precision, &pb);
+
+  osl_int_abs(precision, &pa, a);
+  osl_int_abs(precision, &pb, b);
+
+  osl_int_gcd(precision, &gcd, pa, pb);
+  if (osl_int_zero(precision, gcd)) {
+    osl_int_set_si(precision, lcm, 0);
+  } else {
+    osl_int_div_exact(precision, &pa, pa, gcd);
+    osl_int_mul(precision, lcm, pa, pb);
+  }
+
+  osl_int_clear(precision, &gcd);
+  osl_int_clear(precision, &pa);
+  osl_int_clear(precision, &pb);
+}
+
 
 /**
  * \brief variable = - value
@@ -1139,6 +1172,97 @@ int osl_int_ne(int precision, osl_const_int_t val1, osl_const_int_t val2) {
   return !osl_int_eq(precision, val1, val2);
 }
 
+/**
+ * \brief val1 < val2
+ * \param[in] precision Precision of the osl int
+ * \param[in] val1      Value of first osl int
+ * \param[in] val2      Value of second osl int
+ * \return 1 if val1 is less than val2
+ */
+int osl_int_lt(int precision, osl_const_int_t val1, osl_const_int_t val2) {
+  switch (precision) {
+    case OSL_PRECISION_SP:
+    case OSL_PRECISION_DP:
+      return (val1.sp < val2.sp);
+
+#ifdef OSL_GMP_IS_HERE
+    case OSL_PRECISION_MP:
+      return (mpz_cmp(*val1.mp, *val2.mp) < 0);
+#endif
+
+    default:
+      OSL_error("unknown precision");
+  }
+}
+
+/**
+ * \brief val1 <= val2
+ * \param[in] precision Precision of the osl int
+ * \param[in] val1      Value of first osl int
+ * \param[in] val2      Value of second osl int
+ * \return 1 if val1 is less than or equal to val2
+ */
+int osl_int_le(int precision, osl_const_int_t val1, osl_const_int_t val2) {
+  switch (precision) {
+    case OSL_PRECISION_SP:
+    case OSL_PRECISION_DP:
+      return (val1.sp <= val2.sp);
+
+#ifdef OSL_GMP_IS_HERE
+    case OSL_PRECISION_MP:
+      return (mpz_cmp(*val1.mp, *val2.mp) <= 0);
+#endif
+
+    default:
+      OSL_error("unknown precision");
+  }
+}
+
+/**
+ * \brief val1 > val2
+ * \param[in] precision Precision of the osl int
+ * \param[in] val1      Value of first osl int
+ * \param[in] val2      Value of second osl int
+ * \return 1 if val1 is greater than val2
+ */
+int osl_int_gt(int precision, osl_const_int_t val1, osl_const_int_t val2) {
+  switch (precision) {
+    case OSL_PRECISION_SP:
+    case OSL_PRECISION_DP:
+      return (val1.sp > val2.sp);
+
+#ifdef OSL_GMP_IS_HERE
+    case OSL_PRECISION_MP:
+      return (mpz_cmp(*val1.mp, *val2.mp) > 0);
+#endif
+
+    default:
+      OSL_error("unknown precision");
+  }
+}
+
+/**
+ * \brief val1 >= val2
+ * \param[in] precision Precision of the osl int
+ * \param[in] val1      Value of first osl int
+ * \param[in] val2      Value of second osl int
+ * \return 1 if val1 is greater than or equal to val2
+ */
+int osl_int_ge(int precision, osl_const_int_t val1, osl_const_int_t val2) {
+  switch (precision) {
+    case OSL_PRECISION_SP:
+    case OSL_PRECISION_DP:
+      return (val1.sp >= val2.sp);
+
+#ifdef OSL_GMP_IS_HERE
+    case OSL_PRECISION_MP:
+      return (mpz_cmp(*val1.mp, *val2.mp) >= 0);
+#endif
+
+    default:
+      OSL_error("unknown precision");
+  }
+}
 
 /**
  * \brief value > 0
