@@ -332,9 +332,9 @@ char * osl_util_read_tag(FILE * file, char ** str) {
  * \return The string that has been read.
  */
 char * osl_util_read_uptoflag(FILE * file, char ** str, char * flag) {
-  int high_water_mark = OSL_MAX_STRING;
-  int nb_chars = 0;
-  int lenflag = strlen(flag), lenstr;
+  size_t high_water_mark = OSL_MAX_STRING;
+  size_t nb_chars = 0;
+  size_t lenflag = strlen(flag), lenstr;
   int flag_found = 0;
   char * res;
 
@@ -344,11 +344,10 @@ char * osl_util_read_uptoflag(FILE * file, char ** str, char * flag) {
   OSL_malloc(res, char *, high_water_mark * sizeof(char));
 
   // Copy everything to the res string.
-  if (str != NULL)
-    lenstr = strlen(*str);
+  lenstr = str != NULL ? strlen(*str) : 0;
   while (((str  != NULL) && (nb_chars != lenstr)) ||
          ((file != NULL) && (!feof(file)))) {
-    res[nb_chars++] = (str != NULL) ? *((*str)++) : fgetc(file);
+    res[nb_chars++] = (str != NULL) ? *((*str)++) : (char)fgetc(file);
 
     if ((nb_chars >= lenflag) &&
         (!strncmp(&res[nb_chars - lenflag], flag, lenflag))) {
@@ -433,7 +432,7 @@ char * osl_util_tag_content(char * str, char * name) {
   char * stop;
   char tag[strlen(name) + 3];
   char endtag[strlen(name) + 4];
-  int size = 0;
+  size_t size = 0;
   size_t lentag;
   char * res = NULL;
 
@@ -480,9 +479,9 @@ char * osl_util_tag_content(char * str, char * name) {
  * \param[in]     src string to concatenate to dst.
  * \param[in,out] hwm pointer to the size of the *dst buffer (may be updated).
  */
-void osl_util_safe_strcat(char ** dst, char * src, int * hwm) {
+void osl_util_safe_strcat(char ** dst, char * src, size_t * hwm) {
 
-  while ((int)(strlen(*dst) + strlen(src)) >= *hwm) {
+  while ((strlen(*dst) + strlen(src)) >= *hwm) {
     *hwm += OSL_MAX_STRING;
     OSL_realloc(*dst, char *, *hwm * sizeof(char));
   }
@@ -515,7 +514,7 @@ char * osl_util_strdup(char const * str) {
  * variable or the highest available precision if it is not defined.
  * \return environment precision if defined or highest available precision.
  */
-int osl_util_get_precision() {
+int osl_util_get_precision(void) {
   int precision = OSL_PRECISION_DP;
   char * precision_env;
 
@@ -577,30 +576,35 @@ void osl_util_print_provided(FILE * file, int provided, char * title) {
  */
 static
 int osl_util_identifier_is_here(char * expression, char * identifier,
-                                int index) {
+                                size_t index) {
+  size_t identifier_len = strlen(identifier);
+  size_t expression_len = strlen(expression);
+
   // If there is no space enough to find the identifier: no.
-  if (strlen(identifier) + index > strlen(expression))
+  if (identifier_len + index > expression_len)
     return 0;
   
-  // If there is a character before and it is in [A-Za-z0-9]: no.
+  // If there is a character before and it is in [A-Za-z0-9_]: no.
   if ((index > 0) &&
-      (((expression[index - 1] >= 'A') && (expression[index - 1] <= 'Z')) || 
-       ((expression[index - 1] >= 'a') && (expression[index - 1] <= 'z')) || 
-       ((expression[index - 1] >= '0') && (expression[index - 1] <= '9'))))
+      (((expression[index - 1] >= 'A') && (expression[index - 1] <= 'Z')) ||
+       ((expression[index - 1] >= 'a') && (expression[index - 1] <= 'z')) ||
+       ((expression[index - 1] >= '0') && (expression[index - 1] <= '9')) ||
+        (expression[index - 1] == '_')))
     return 0;
 
-  // If there is a character after and it is in [A-Za-z0-9]: no.
-  if ((strlen(identifier) + index < strlen(expression)) &&
-      (((expression[strlen(identifier) + index] >= 'A') &&
-        (expression[strlen(identifier) + index] <= 'Z'))   || 
-       ((expression[strlen(identifier) + index] >= 'a') &&
-        (expression[strlen(identifier) + index] <= 'z'))   || 
-       ((expression[strlen(identifier) + index] >= '0') &&
-        (expression[strlen(identifier) + index] <= '9'))))
+  // If there is a character after and it is in [A-Za-z0-9_]: no.
+  if ((identifier_len + index < expression_len) &&
+      (((expression[identifier_len + index] >= 'A') &&
+        (expression[identifier_len + index] <= 'Z'))   ||
+       ((expression[identifier_len + index] >= 'a') &&
+        (expression[identifier_len + index] <= 'z'))   ||
+       ((expression[identifier_len + index] >= '0') &&
+        (expression[identifier_len + index] <= '9'))   ||
+       ( expression[identifier_len + index] == '_')))
     return 0;
 
   // If the identifier string is not here: no.
-  if (strncmp(expression + index, identifier, strlen(identifier)))
+  if (strncmp(expression + index, identifier, identifier_len))
     return 0;
 
   return 1;
@@ -623,36 +627,38 @@ int osl_util_identifier_is_here(char * expression, char * identifier,
  */
 static
 int osl_util_lazy_isolated_identifier(char * expression, char * identifier,
-                                      int index) {
-  int look;
+                                      size_t index) {
+  size_t look;
+  size_t expression_len = strlen(expression);
+  size_t identifier_len = strlen(identifier);
 
   // If the first non-space character before is not in [\[(,\+=]: no. 
   look = index - 1;
-  while (look >= 0) {
+  while (look < index) {
     if (isspace(expression[look]))
       look--;
     else
       break;
   }
 
-  if ((look >= 0) &&
+  if ((look < index) &&
       (expression[look] != '[') &&
       (expression[look] != '(') &&
       (expression[look] != '+') &&
       (expression[look] != '=') &&
       (expression[look] != ','))
     return 0;
-        
+
   // If the first non-space character after is not in [\]),;\+]: no. 
-  look = index + strlen(identifier);
-  while (look < (int)strlen(expression)) {
+  look = index + identifier_len;
+  while (look < expression_len) {
     if (isspace(expression[look]))
       look++;
     else
       break;
   }
 
-  if ((look < (int)strlen(expression)) &&
+  if ((look < expression_len) &&
       (expression[look] != ']')   &&
       (expression[look] != ')')   &&
       (expression[look] != '+')   &&
@@ -683,7 +689,7 @@ char * osl_util_identifier_substitution(char * expression,
                                         char ** identifiers) {
   size_t index;
   int j, found;
-  int high_water_mark = OSL_MAX_STRING;
+  size_t high_water_mark = OSL_MAX_STRING;
   char buffer[OSL_MAX_STRING];
   char * string;
  
