@@ -214,6 +214,7 @@ static void free_clast_for(struct clast_stmt *s)
     if (f->private_vars) free(f->private_vars);
     if (f->reduction_vars) free(f->reduction_vars);
     if (f->time_var_name) free(f->time_var_name);
+    if (f->user_directive) free(f->user_directive);
     free(f);
 }
 
@@ -233,6 +234,7 @@ struct clast_for *new_clast_for(CloogDomain *domain, const char *it,
     f->private_vars = NULL;
     f->reduction_vars = NULL;
     f->time_var_name = NULL;
+    f->user_directive = NULL;
     cloog_int_init(f->stride);
     if (stride)
 	cloog_int_set(f->stride, stride->stride);
