@@ -460,6 +460,8 @@ static int annotate_loops(osl_scop_p program, struct clast_stmt *root){
     clast_filter(root, filter, &clastloops, &nclastloops, 
                  &claststmts, &nclaststmts);
 
+    if (claststmts) { free(claststmts); claststmts=NULL;}
+
     /* There should be at least one */
     if (nclastloops==0) {  //FROM PLUTO
        /* Sometimes loops may disappear (1) tile size larger than trip count
@@ -483,10 +485,18 @@ static int annotate_loops(osl_scop_p program, struct clast_stmt *root){
           clastloops[j]->private_vars = strdup(loop->private_vars);
         }
       }
+
+      if (loop->directive & CLAST_PARALLEL_USER) {
+        clastloops[j]->parallel |= CLAST_PARALLEL_USER;
+        ret |= CLAST_PARALLEL_USER;
+        if (loop->user) {
+          clastloops[j]->user_directive = strdup(loop->user);
+        }
+      }
+
     }
 
     if (clastloops) { free(clastloops); clastloops=NULL;}
-    if (claststmts) { free(claststmts); claststmts=NULL;}
 
     ll = ll->next;
   }
